using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Drawing.Imaging;
using System.Windows.Forms;
using System.IO;

namespace YokohabaHanbun
{
    public partial class Form1 : Form
    {
        public Form1()
        {
            InitializeComponent();
        }

        private void Form1_DragEnter(object sender, DragEventArgs e)
        {
            if (e.Data.GetDataPresent(DataFormats.FileDrop))
                e.Effect = DragDropEffects.All;
            else
                e.Effect = DragDropEffects.None;
        }

        private void Form1_DragDrop(object sender, DragEventArgs e)
        {
            try
            {
                string[] filenames = (string[])e.Data.GetData(DataFormats.FileDrop, false);

                this.progressBar.Value = 0;
                this.progressBar.Maximum = filenames.GetUpperBound(0);
                this.label.Text = "...";
                this.Update();

                foreach (string filename in filenames)
                {

                    this.TrimImage(filename);
                    this.progressBar.Increment(1);

                    this.label.Text = string.Format("...{0}/{1}", this.progressBar.Value, this.progressBar.Maximum);
                    this.Update();
                }
            }
            catch (Exception ex)
            {
                MessageBox.Show(ex.Message);
            }

            this.progressBar.Value = 0;
            this.label.Text = "";
        }

        private void TrimImage(string filename)
        {
            Image imageNew;

            using (Image image = Image.FromFile(filename))
            {
                imageNew = new Bitmap(image.Width / 2, image.Height);
                if (this.radioLeft.Checked)
                {
                    Graphics.FromImage(imageNew).DrawImage(image, 0, 0);
                }
                else if (this.radioRight.Checked)
                {
                    Graphics.FromImage(imageNew).DrawImage(image, -imageNew.Width, 0);
                }
            }

            string ext = new FileInfo(filename).Extension.ToLower();

            ImageCodecInfo imageCodecInfo;
            EncoderParameters encoderParameters;

            switch (ext)
            {
                case ".jpg":

                    imageCodecInfo = GetEncoderInfo("image/jpeg");
                    encoderParameters = new EncoderParameters(1);
                    encoderParameters.Param[0] = new EncoderParameter(Encoder.Quality, (long)(this.jpgQuality.Value));
                    imageNew.Save(filename, imageCodecInfo, encoderParameters);

                    break;
            }

        }

        private static ImageCodecInfo GetEncoderInfo(String mimeType)
        {
            int j;
            ImageCodecInfo[] encoders;
            encoders = ImageCodecInfo.GetImageEncoders();
            for (j = 0; j < encoders.Length; ++j)
            {
                if (encoders[j].MimeType == mimeType)
                    return encoders[j];
            }
            return null;
        }

    }
}